@@ -1,6 +1,6 @@
 package Bundle::Lingua::PT;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 =head1 NAME
 
@@ -23,6 +23,8 @@ If you think some useful module is missing let us know.
 
 Text::Ngram
 
+Text::WordGrams
+
 Text::Affixes
 
 Lingua::Identify
@@ -51,6 +53,10 @@ Lingua::PT::Words2Nums
 
 Lingua::PT::Speaker
 
+Lingua::Jspell
+
+Tie::Ispell
+
 =head1 AUTHOR
 
 Alberto Simes, C<< <ambs@cpan.org> >>
